pub struct Cli {Show 30 fields
pub db: String,
pub query: Option<String>,
pub query_arg: Option<String>,
pub trace: bool,
pub auto_create_missing_references: bool,
pub structure: Option<u32>,
pub before: bool,
pub changes: bool,
pub after: bool,
pub lino_input: Option<String>,
pub lino_output: Option<String>,
pub always: bool,
pub once: bool,
pub never: bool,
pub triggers: bool,
pub triggers_file: Option<String>,
pub embed_triggers: bool,
pub transactions: bool,
pub transactions_file: Option<String>,
pub commit_mode: Option<String>,
pub retention: Option<String>,
pub vc: bool,
pub vc_file: Option<String>,
pub branch: Option<String>,
pub branch_from: Option<i64>,
pub checkout: Option<String>,
pub tag: Option<String>,
pub list_branches: bool,
pub list_tags: bool,
pub show_log: bool,
}Fields
db: Stringquery: Option<String>query_arg: Option<String>trace: boolauto_create_missing_references: boolstructure: Option<u32>before: boolchanges: boolafter: boollino_input: Option<String>lino_output: Option<String>always: boolonce: boolnever: booltriggers: booltriggers_file: Option<String>embed_triggers: booltransactions: booltransactions_file: Option<String>commit_mode: Option<String>retention: Option<String>vc: boolvc_file: Option<String>branch: Option<String>branch_from: Option<i64>checkout: Option<String>tag: Option<String>list_branches: boolshow_log: boolImplementations
Sourceimpl Cli
impl Cli
Sourcepub fn transactions_requested(&self) -> bool
pub fn transactions_requested(&self) -> bool
True when any flag in the transactions decorator family was passed.
Sourcepub fn trigger_command_count(&self) -> usize
pub fn trigger_command_count(&self) -> usize
True when a trigger command — --always, --once or --never — was
passed. Exactly one of them may be used at a time.
Sourcepub fn persistent_transformations_requested(&self) -> bool
pub fn persistent_transformations_requested(&self) -> bool
True when any flag in the persistent transformation family was passed.
Mirrors persistentTransformationsEnabled in the C# tool, minus the
“the triggers file already exists” clause, which needs the resolved
path and therefore lives next to it in main.
Sourcepub fn vc_requested(&self) -> bool
pub fn vc_requested(&self) -> bool
True when any flag in the version-control decorator family was passed.
pub fn parse() -> Result<CliCommand>
pub fn parse_from<I, T>(args: I) -> Result<CliCommand>
pub fn print_help()
pub fn help_text() -> &'static str
pub fn version_text() -> String