Module link

Module link 

Link - A doublet (source, target) pair with an index

This module provides the core link data structure that represents a link in the doublet storage.

The structure is generic over the link address type (GenericLink) so that the storage and transactions layers can be reused with any address width supported by doublets (u32, u64, usize, …). Link is the u32 specialisation used by the clink CLI itself.

Structs

GenericLink
A doublet (source, target) pair together with its own address.

Type Aliases

DoubletsLink
Link type from the upstream doublets crate used as the Rust basis.
Link
The u32-addressed link used by the clink CLI and its decorators.