UniquenessPolicy

Trait UniquenessPolicy 

pub trait UniquenessPolicy {
    type Decorator<T: LinkReference, L: Doublets<T>>: Doublets<T>;

    // Required method
    fn decorate<T, L>(links: L) -> Self::Decorator<T, L>
       where T: LinkReference,
             L: Doublets<T>;
}
Selects how a store reacts when an update would produce a duplicate (source, target) pair.

Implemented by Validate, Resolve and CascadeResolve.

Required Associated Types

type Decorator<T: LinkReference, L: Doublets<T>>: Doublets<T>

The decorator this policy wraps a store in.

Required Methods

fn decorate<T, L>(links: L) -> Self::Decorator<T, L>
where T: LinkReference, L: Doublets<T>,

Wraps links in the decorator selected by this policy.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl UniquenessPolicy for CascadeResolve



type Decorator<T: LinkReference, L: Doublets<T>> = CascadeUniquenessAndUsagesResolver<T, L>



impl UniquenessPolicy for Resolve



type Decorator<T: LinkReference, L: Doublets<T>> = UniquenessResolver<T, L>



impl UniquenessPolicy for Validate



type Decorator<T: LinkReference, L: Doublets<T>> = UniquenessValidator<T, L>