pub struct Link {
pub index: u32,
pub source: u32,
pub target: u32,
}Expand description
Link represents a doublet (source, target) pair with an index
Fields
index: u32source: u32target: u32Implementations
Sourceimpl Link
impl Link
Sourcepub fn new(index: u32, source: u32, target: u32) -> Self
pub fn new(index: u32, source: u32, target: u32) -> Self
Creates a new link with the given index, source, and target
Sourcepub fn is_full_point(&self) -> bool
pub fn is_full_point(&self) -> bool
Returns true if this is a full point (self-referential link)
Sourcepub fn is_partial_point(&self) -> bool
pub fn is_partial_point(&self) -> bool
Returns true if this link references itself from at least one side.