pub fn simplify_changes(changes: Vec<(Link, Link)>) -> Vec<(Link, Link)>Expand description
Simplifies a list of changes by identifying chains of transformations.
If multiple final states are reachable from the same initial state, returns multiple simplified changes. If a scenario arises where no initial or final states can be identified (no-ops), returns the original transitions as-is.