pub struct RemoteLinks { /* private fields */ }Expand description
A links store served by a LinksServer, usable
wherever a local store is.
Implementations
Sourceimpl RemoteLinks
impl RemoteLinks
Sourcepub fn connect(
address: impl ToSocketAddrs,
protocol: impl LinoProtocol + 'static,
) -> ProtocolResult<Self>
pub fn connect( address: impl ToSocketAddrs, protocol: impl LinoProtocol + 'static, ) -> ProtocolResult<Self>
Connects to the server at address.
Sourcepub fn new(client: LinksClient) -> Self
pub fn new(client: LinksClient) -> Self
Uses an existing connection.
Sourcepub fn execute(
&self,
operation: &LinksOperation,
) -> ProtocolResult<LinoDocument>
pub fn execute( &self, operation: &LinksOperation, ) -> ProtocolResult<LinoDocument>
Runs one operation on the server and returns its reply.
Sourcepub fn count_matching(&self, restriction: &[Part]) -> ProtocolResult<u32>
pub fn count_matching(&self, restriction: &[Part]) -> ProtocolResult<u32>
Number of links matching restriction.
Sourcepub fn links_matching(&self, restriction: &[Part]) -> ProtocolResult<Vec<Link>>
pub fn links_matching(&self, restriction: &[Part]) -> ProtocolResult<Vec<Link>>
Links matching restriction, ordered by index.
Sourcepub fn changes(&self, operation: &LinksOperation) -> ProtocolResult<Vec<Change>>
pub fn changes(&self, operation: &LinksOperation) -> ProtocolResult<Vec<Change>>
Runs a create, update or delete and returns its changes.